# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-EV
Version:	4.34
Release:	7.%{__distinit}%{__distvers}
Summary:	Wrapper for the libev high-performance event loop library
# libev: BSD-2-Clause OR GPL-2.0-or-later
# Perl interface: GPL-1.0-or-later OR Artistic-1.0-Perl
License:	(BSD-2-Clause OR GPL-2.0-or-later) AND (GPL-1.0-or-later OR Artistic-1.0-Perl)
URL:		https://metacpan.org/release/EV
Source0:	https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/EV-%{version}.tar.gz
Patch10:	EV-4.34-FTBFS-with-ExtUtils::ParseXS-3.57.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	gdbm-devel
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(AnyEvent) >= 5.29
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:	perl(strict)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(common::sense)
BuildRequires:	perl(Config)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Socket)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Provides:	bundled(libev) = 4.34

%{?perl_default_filter}

%description
This module provides an interface to libev
(<http://software.schmorp.de/pkg/libev.html>).

%prep
%setup -q -n EV-%{version}

# Fix FTBFS with ExtUtils::ParseXS ≥ 3.57 (rhbz#2364628)
# Fix from https://github.com/Perl/perl5/issues/22353
%patch -P10

%build
PERL_CANARY_STABILITY_NOPROMPT=1 perl Makefile.PL \
	INSTALLDIRS=vendor \
	NO_PACKLIST=1 \
	NO_PERLLOCAL=1 \
	OPTIMIZE="%{optflags}" < /dev/null
%{make_build}

%install
%{make_install}
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc Changes README
%dir %{perl_vendorarch}/EV/
%doc %{perl_vendorarch}/EV/libev.pod
%{perl_vendorarch}/EV.pm
%{perl_vendorarch}/EV/*.h
%{perl_vendorarch}/EV/MakeMaker.pm
%{perl_vendorarch}/auto/EV/
%{_mandir}/man3/EV.3*
%{_mandir}/man3/EV::MakeMaker.3*
%{_mandir}/man3/EV::libev.3*

%changelog
* Wed May  7 2025 Paul Howarth <paul@city-fan.org> - 4.34-7
- Fix FTBFS with ExtUtils::ParseXS ≥ 3.57 (rhbz#2364628)
- Use %%{make_build} and %%{make_install}

* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 4.34-4
- Perl 5.40 rebuild

* Mon Oct  9 2023 Paul Howarth <paul@city-fan.org> - 4.34-1
- Update to 4.33
  - The EV::stat->path method erroneously freed the result, causing corruption
  - New function EV::Child::reinit

* Thu Jul 13 2023 Paul Howarth <paul@city-fan.org> - 4.33-12
- Use SPDX-format license tag
- Add provide for bundled libev

* Thu Jun  2 2022 Paul Howarth <paul@city-fan.org> - 4.33-9
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 4.33-6
- Perl 5.34 rebuild

* Sat Jun 27 2020 Paul Howarth <paul@city-fan.org> - 4.33-2
- Perl 5.32 rebuild

* Thu Mar 19 2020 Paul Howarth <paul@city-fan.org> - 4.33-1
- Update to 4.33
  - The enable assertion makefile question failed to enable assertions due to a
    typo
  - Try harder to avoid perl's assert(), which does not actually behave
    correctly
  - Updated libecb to make it compile under more Windows environments

* Fri Jan 24 2020 Paul Howarth <paul@city-fan.org> - 4.32-1
- Update to 4.32
  - (libev) Fixed a bug introduced in 4.31 when timerfds and signalfds were
    used at the same time
  - (libev) Zero is now allowed as requested event mask in IO watchers
  - (libev) Once-per-minute wakeups will now be optimized away when timerfds
    are available
  - Use the new ev_io_modify in EV::IO->events, instead of the potentially
    slower ev_io_set
  - Add a bunch of mutator methods, mostly untested(!): EV::Timer->repeat,
    EV::Periodic->offset, EV::Periodic->interval, EV::Periodic->reschedule_cb
  - Minor optimizations and bugfixes

* Sat Dec 21 2019 Paul Howarth <paul@city-fan.org> - 4.31-1
- Update to 4.31
  - (libev) Handle backends with minimum wait time a bit better by not waiting
    in the presence of already-expired timers
  - (libev) Use timerfd to detect time jumps
  - (libev) New loop flag: EVFLAG_NOTIMERFD

* Sat Nov 23 2019 Paul Howarth <paul@city-fan.org> - 4.30-1
- Update to 4.30
  - (libev) Use a different and hopefully even more portable test to disable
    io_uring when header files are too old, by directly testing
    LINUX_VERSION_CODE
  - (libev) Fix a bug in the io_uring backend that polled the wrong backend fd,
    causing it not to work in many cases

* Fri Nov 22 2019 Paul Howarth <paul@city-fan.org> - 4.29-1
- Update to 4.29
  - (libev) Add io uring autoconf and non-autoconf detection, the latter of
    which should disable io_uring compilation on old systems

* Tue Nov 19 2019 Paul Howarth <paul@city-fan.org> - 4.28-1
- Update to 4.28
  - (libev) Fix ev_port backend
  - (libev) Many bugfixes in linuxaio backend
  - (libev) Experimental io uring interface
  - Try to name ev.h more explicitly, hopefully improving portability
  - Opportunistically round up wait times for poll and epoll backend, to avoid
    unnecessary loop iterations
  - Add build dependency on ev_linuxaio.c
  - Quickly (re)-ported to minix 3.3 before minix crashed again

* Thu Jun 27 2019 Paul Howarth <paul@city-fan.org> - 4.27-1
- Update to 4.27
  - (libev) Completely rewritten linuxaio backend, may be usable as a
    general-use backend
  - (libev) Use more aggressive assertions to catch more usage errors
  - Allow users to re-enable assert() in case it is disabled by perl (which is
    typically the case)

* Tue Jun 25 2019 Paul Howarth <paul@city-fan.org> - 4.26-1
- Update to 4.26
  - (libev) Included experimental linux aio backend
  - Allow the linux aio backend to be used by default only when explicitly
    configured during Makefile.PL time

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 4.25-3
- Perl 5.30 rebuild

* Fri Dec 21 2018 Paul Howarth <paul@city-fan.org> - 4.25-1
- Update to 4.25
  - (libev) Updated to libev 4.25, minor fixes and enhancements
  - Document the requirement to "use EV" when using EV::MakeMaker
  - Only use __register_atfork with glibc and uclibc, as musl defines
    __linux__, but doesn't implement the linux standard base ABI, nor makes
    itself detectable via a macro, both apparently by design, winning the
    "broken by design 2016 award" - well done
  - Correct EV::periodic example 24h after midnight → one day after midnight

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 4.22-10
- Perl 5.28 rebuild

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 4.22-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Wed Jun 14 2017 Paul Howarth <paul@city-fan.org> - 4.22-4
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Mon Aug 22 2016 Paul Howarth <paul@city-fan.org> - 4.22-2
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Mon Dec 21 2015 Paul Howarth <paul@city-fan.org> - 4.22-1
- Update to 4.22
  - (libev) When epoll detects unremovable fds in the fd set, rebuild only the
    epoll descriptor, not the signal pipe, to avoid SIGPIPE in ev_async_send;
    this doesn't solve it on fork, so document what needs to be done in
    ev_loop_fork
  - (libev) Remove superfluous sys/timeb.h include on win32
  - Updated libecb
- Explicitly BR: perl-devel, needed for EXTERN.h

* Tue Jul 14 2015 Paul Howarth <paul@city-fan.org> - 4.21-1
- Update to 4.21
  - Allow argument in timer->again
  - Document timer->remaining
  - Document default repeat value for timer->set

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 4.20-1
- Update to 4.20
  - Added stability canary support
  - Truly rely on automatic configuration for clock_gettime and others;
    unfortunately, this doesn't help with activeperl and similar perls, which
    define _POSIX_TIMERS without actually implementing any of it
  - (libev, ecb) Make it compile as C++ again
  - (libev) Fix a potential aliasing issue when accessing watcher callbacks
- Classify buildreqs by usage

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 4.18-1
- Update to 4.18
  - Use slightly better way to find includes, to support multiarch on newer
    perls
- Use %%license where possible

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 4.17-1
- Update to 4.17
  - perl5porters broke Async::Interrupt, BDB, EV, IO::AIO and OpenCL without
    warning by switching the meaning of USE_SOCKETS_AS_HANDLES in 5.18
- Drop %%defattr, redundant since rpm 4.4

* Sat Mar  8 2014 Paul Howarth <paul@city-fan.org> - 4.16-1
- Update to 4.16
  - Make sure EV::CHECK is available at all times
  - Avoid a spurious warning when perl -w overrides "no warnings"
  - Use perl's signal implementation on WIN32
  - Ensure extern "C" function pointers are used for externally-visible
    pointers
  - (libev) mark event pipe fd as cloexec after a fork
  - (ecb) support m68k, m88k and sh
  - (libev) in the absence of autoconf, do not use the clock syscall on
    glibc ≥ 2.17 (avoids the syscall AND -lrt on systems doing clock_gettime
    in userspace)
  - (ecb) work around memory barriers and volatile apparently both being broken
    in Visual Studio 2008 and later

* Fri Mar  1 2013 Paul Howarth <paul@city-fan.org> - 4.15-1
- Update to 4.15
  - (libev) upgrade to 4.15 - too many changes to list
  - EV::run now returns a boolean
  - API version 5:1
    - Document that cleanup watchers are not available via perl
    - Cast I32 to int in error message printf
    - Remove dependencies on librt and libpthreads on GNU/Linux

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 4.11-2
- Use local dist tag definition rather than %%{?dist}
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Drop rpath-fixing kludge

* Sun Feb  5 2012 Paul Howarth <paul@city-fan.org> - 4.11-1
- Update to 4.11
  - libev: Implement memory fences for (obsolete) llvm-gcc

* Thu Jan 19 2012 Paul Howarth <paul@city-fan.org> - 4.10-1
- Update to 4.10
  - libev: Fix a race where the workaround against the epoll fork bugs caused
    signals to not be handled anymore
  - libev: Correct backend_fudge for most backends, and implement a Windows
    specific workaround to avoid looping because we call both select and Sleep,
    with different time resolutions
  - e_new wasn't declared static (causing very minor .so bloat)
  - replace more old API names by new ones
- BR: perl(Config)

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 4.03-6
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Install into vendor directories rather than perl directories
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jan 26 2011 Paul Howarth <paul@city-fan.org> - 4.03-2
- Import from Fedora review queue (#448613)
- Always build with bundled libev

* Mon Jan 24 2011 Mathieu Bridon <bochecha@fedoraproject.org> - 4.03-1
- Update to 4.03

* Sun Nov  8 2009 kwizart < kwizart at gmail.com > - 3.8-1
- Update to 3.8

* Tue Apr 28 2009 kwizart < kwizart at gmail.com > - 3.6-1
- Update to 3.6

* Mon Mar  2 2009 kwizart < kwizart at gmail.com > - 3.53-1
- Update to 3.53

* Tue Feb  3 2009 kwizart < kwizart at gmail.com > - 3.52-1
- Update to 3.52

* Tue Oct 14 2008 kwizart < kwizart at gmail.com > - 3.44-1
- Update to 3.44
- WIP conditional --with systemlibev

* Tue Jul 15 2008 kwizart < kwizart at gmail.com > - 3.431-1
- Update to 3.431
- Update License to (GPL+ or Artistic) and (BSD or GPLv2+)
- Add libev README and LICENSE

* Tue Jul  8 2008 kwizart < kwizart at gmail.com > - 3.43-1
- Update to 3.43

* Mon Jun  9 2008 kwizart < kwizart at gmail.com > - 3.42-2
- Disable filter AnyEvent

* Tue May 27 2008 kwizart < kwizart at gmail.com > - 3.42-1
- Update to 3.42

* Wed Apr 30 2008 kwizart < kwizart at gmail.com > - 3.31-1
- Initial package for Fedora
